#!/usr/bin/env ruby
#
# Net Responsibility
#
# Copyright (C) 2007-2011 Scott Severance & Robert Rosman
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of the
# License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
# 02111-1307, USA.
#
# Author:
#	Scott Severance <http://www.scottseverance.us>
#
#
#
module List_generator
	def mk_file_list(args)
		o = {:source => nil, :dest => nil, :type => 'f', :mode => 0644,
			:owner => 'root', :group => 'root', :options => nil}.merge(args)
		l = "%s %04o %s %s %s %s %s" % [o[:type], o[:mode], o[:owner], o[:group],
											o[:dest], o[:source], o[:options]]
		l.chop! if l =~ / $/
		l
	end
	
	def mk_symlink(args)
		o = {:target => nil, :link => nil, :mode => 0, :type => 'l'}.merge(args)
		o[:source] = o[:target]
		o[:dest] = o[:link]
		mk_file_list o
	end
	
	def set_runlevels
		a = ''
		[2,3,4,5].each {|r| a += "runlevel(%02d) start(%02d) " % [r,50]}
		[0,1,6].each {|r| a += "runlevel(%02d) start(%02d) " % [r,50]}
		'"%s"' % a.chop
	end
	
	def to_f_lines(arr)
		arr.each do |f|
			$epm_f_lines.push(mk_file_list(f))
		end
	end
	
	def get_icon_sizes
		a = []
		Dir.open(File.expand_path('src/images')) do |file|
			file.each do |filename|
				next unless filename =~ /logo_([\d]+)\.png/i
				a.push $1.to_i
			end
		end
		a.sort
	end
	
	def list_files(dir,basedir)
		basedir += '/'
		basedir.gsub!(Regexp.new('//'), '/')
		Dir.open dir do |file|
			file.each do |f|
				next if f =~ /^\./
				basename = File.basename(f).gsub(/^src$/,'net-responsibility')
				full_path = File.expand_path(basedir + "/#{f}")
				if File.directory? full_path
					$files.push({:source => "-",
						:dest   => "/usr/share/#{basedir + basename}",
						:type   => 'd',
						:mode   => 0755,
					})
					list_files(full_path, basedir + "/#{basename}/")
				else
					$files.push({:source => basedir + basename,
						:dest   => "/usr/share/#{basedir + basename}",
						:type   => "f",
						:mode   => if basename =~ /\.[a-z0-9]+$/i
										0644
									else
										0755
									end
				 })
				end
			end
		end
	end
end
