raise "Can't run this file directly" unless defined? $lib_dir
# Net Responsibility
#
# Copyright (C) 2007-2011 Scott Severance & Robert Rosman
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of the
# License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
# 02111-1307, USA.
#
# Author:
#	Scott Severance <http://www.scottseverance.us>

require "#{$lib_dir}exceptions"
require "#{$lib_dir}options"

# Required template variables:
# - name
# - email_from
# - email_to (Array)
# - use_smtp (Bool)
# - server (default to localhost)
# - port (defautl to 25)
# - login_name
# - password
# - authentication (bool)
# - use_tls (bool)

class Config_writer
	@@supported_settings = %w[name email_to email_from use_smtp server port login_name password helo_name]
	
	def initialize(options = Options.new)
		@options = options
		@configfile = options.config
		@template_file = "#{File.dirname(File.expand_path($lib_dir))}/net-responsibility.conf.tmpl"
	end
	
	def self.supported?(setting)
		@@supported_settings.include?(setting.to_s)
	end
	
	def write
		name, email_from, email_to, use_smtp, server, port, login_name, password, authentication, use_tls = get_options(true)
		t = ''
		email_to.to_a.each {|i| t += "  - #{i}\\n" }
		email_to = t
		f = File.new @template_file
		template = f.gets(nil).gsub /"/, '\"'
		f.close
		template_str  = "name = \"#{name}\"\n"
		template_str += "email_from = \"#{email_from}\"\n"
		template_str += "email_to = \"#{email_to}\"\n"
		template_str += "use_smtp = \"#{use_smtp}\"\n"
		template_str += "server = \"#{server}\"\n"
		template_str += "port = \"#{port}\"\n"
		template_str += "login_name = \"#{login_name}\"\n"
		template_str += "password = \"#{password}\"\n"
		template_str += "authentication = \"#{authentication}\"\n"
		template_str += "use_tls = \"#{use_tls}\"\n"
		template_str += "\"#{template}\""
		#puts(eval(template_str))
		File.open(@configfile, 'w') { |f| f.puts(eval(template_str)) }
	end
	
	private
	
	def get_options(escape = false)
		o = @options
		name       = if o.respond_to? :name
									o.name
								else ""
								end
		email_from = if o.respond_to? :email_from
									o.email_from
								else "root@%s" % `hostname --fqdn`.chomp
								end
		email_to   = if o.respond_to? :email_to
									o.email_to
								else
									raise(NoEmailToAddressError,
										"No e-mail to address specified")
								end
		use_smtp   = if o.respond_to?(:smtp_server) && o.smtp_server.has_key?('use_smtp')
									o.smtp_server['use_smtp']
								else true
								end
		server     = if o.respond_to?(:smtp_server) && o.smtp_server.has_key?('server')
									o.smtp_server['server']
								else "localhost"
								end
		port       = if o.respond_to?(:smtp_server) && o.smtp_server.has_key?('port')
									o.smtp_server['port']
								else 25
								end
		login_name = if o.respond_to?(:smtp_server) && o.smtp_server.has_key?('login_name')
									o.smtp_server['login_name']
								else false
								end
		password   = if o.respond_to?(:smtp_server) && o.smtp_server.has_key?('password')
									o.smtp_server['password']
								else false
								end
		authentication = if o.respond_to?(:smtp_server) && o.smtp_server.has_key?('authentication')
										o.smtp_server['authentication']
								else false
								end
		use_tls    = if o.respond_to?(:smtp_server) && o.smtp_server.has_key?('use_tls')
									o.smtp_server['use_tls']
								else false
								end
		opts = [name, email_from, email_to, use_smtp, server, port, login_name, password, authentication, use_tls]
		if escape
			t = []
			opts.each do |i|
				if i.class == Array
					t2 = []
					i.each {|j| t2.push(j.to_s.gsub(/"/, '\"'))}
					t.push t2
				else 
					t.push(i.to_s.gsub(/"/,'\"'))
				end
			end
			t
		else
			opts
		end
	end
end
