raise "Can't run this file directly" unless defined? $lib_dir
# Net Responsibility
#
# Copyright (C) 2007-2011 Scott Severance & Robert Rosman
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of the
# License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
# 02111-1307, USA.
#
# Author:
#	Scott Severance <http://www.scottseverance.us>

require "#{$lib_dir}options"

class Filter
	def initialize(options = Options.new)
		@blacklist = options.blacklist
		@whitelist = options.whitelist
	end
		
	def token_match(url)
		url_dup = url.dup
		matched = []
		tokens = split_url(url_dup)
		tokens.each do |token|
			token = list_match(token)
			matched.push(token) if token
		end
		
		if not matched.empty?
			matched_hash = {}
			matched.each do |m|	
				m.each_pair do |match_word, cat|
					url_dup = make_bold(url_dup, match_word)
					matched_hash[unRegexpalize(match_word)] = cat
				end
			end
			return {"boldURL" => url_dup, "URL" => url, "match" => matched_hash}
		else
			return false
		end
		
	end
	
	def url_match(url, list = @blacklist)
		url_dup = url.dup
		matched = list_match(url_dup, list)
		if matched
			matched_hash = {}
			matched.each_pair do |match_word, cat|
				url_dup = make_bold(url_dup, match_word)
				matched_hash[unRegexpalize(match_word)] = cat
			end
			return {"boldURL" => url_dup, "URL" => url, "match" => matched_hash}
		else
			return false
		end
	end
	
	def list_match(str, list = @blacklist)
		matched_words = {}
		list.each_pair do |cat, wordArray|
			wordArray.each do |words|
				m = words.match(" ") ? words.split(/\s+/) : [words]
				m.length.times do |i|
					begin
						if(str.match(Regexp.new(m[i], true)))
							matched_words[words] = cat if i == m.length-1
						else
							break
						end
					rescue RegexpError => e
						puts "Invalid Regular Expression!\n%s (%s)\n\n%s" % [words, cat, e]
						break
					end
				end
			end
		end

		return matched_words.empty? ? false : matched_words
	end

	private
	
	def make_bold(url, words)
		m = words.match(/\s+/) ? words.split(" ") : [words]
		m.length.times do |j|
			url.gsub!(Regexp.new(m[j], true)) {|makeBold| '<b>'+makeBold+'</b>' if makeBold.length > 0 }
		end
		return url
	end
	
	def split_url(url)
		unigrams = url.dup
		unigrams = unigrams.split(/((\?|\&).*?\=)|\//)
		unigrams.delete_if{|x| x.length <2}
		unigrams.uniq!
		
		return unigrams
	end

	def unRegexpalize(reg)
		reg = reg.dup
		reg.gsub!(/\(.*\)\?/, "")
		reg.gsub!(/\(([^\|]+).*\)/, '\1')
		reg.gsub!(/.\?/, "")
		reg.gsub!(/[^a-zA-Z\s]/, "")
		return reg
	end
end
