raise "Can't run this file directly" unless defined? $lib_dir
# Net Responsibility
#
# Copyright (C) 2007-2011 Scott Severance & Robert Rosman
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of the
# License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
# 02111-1307, USA.
#
# Author:
#	Scott Severance <http://www.scottseverance.us>

require "net/http"
require "uri"

module Misc
	def check_for_root
		user = `whoami`.chomp
		unless user =~ /^root$/
			puts 'ERROR: This program must be run as root'
			exit(2)
		end
	end
	
	def program_name
		$0.gsub Regexp.new("^.*/([^/]*)$"), '\1'
	end
	
	def daemon_pid(pidfile)
		pid = nil
		return false unless File.exists? pidfile
		File.open(pidfile) do |f|
			f.each {|l| pid = l.chomp}
		end
		pid
	end
	
	def delete_attached_reports(date)
		old_reports = `ls #{$lib_dir}reports/ |egrep -v "report_#{date}_.*\.(htm|zip)"|egrep "report.*\.(htm|zip)"`
		old_reports.each do |filename|
			`rm -rfv #{$lib_dir}reports/#{filename.chomp!}`
		end
	end
	
	#returns true if no other instance exists; false otherwise
	def ensure_single_instance(pidfile)
		return true unless File.exists?(pidfile)
		
		# Get pid
		pid = nil
		File.open(pidfile) do |file|
			file.each {|line| pid = line.chomp }
		end
		
		# If the pidfile is stale, delete it
		`ps -ef | awk '{print $2}' | grep #{pid} > /dev/null 2>&1`
		if $?.exitstatus != 0
			File.delete pidfile
			return true
		end
		#unless File.exists? "/proc/#{pid}"
		#  File.delete pidfile
		#  return true
		#end
		
		# Otherwise, kill the previous daemon
		tries = 0
		kill_str = "kill -SIGTERM #{pid}"
		begin
			tries += 1
			`#{kill_str}`
			unless $?.exitstatus == 0
				raise "Another instance of #{$0} is currently running and refuses to exit after #{tries} tries."
			end
			#File.delete(pidfile) if File.exists?(pidfile)
		rescue
			sleep 1
			retry if tries <= 4
			raise
		end
		false
	end
	# The name check_single_instance is deprecated because it incorrectly
	# implies no side effects.
	alias_method :check_single_instance, :ensure_single_instance
end
