raise "Can't run this file directly" unless defined? $lib_dir
# Net Responsibility
#
# Copyright (C) 2007-2011 Scott Severance & Robert Rosman
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of the
# License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
# 02111-1307, USA.
#
# Author:
#	Scott Severance <http://www.scottseverance.us>

require "uri"
require 'getoptlong'
require 'yaml'
require "#{$lib_dir}my_date"
require "#{$lib_dir}modules/misc"
require "#{$lib_dir}server_connection"

class Options
	include Misc

	def initialize
		set_version
		set_options
		settings = read_config(@config)
		settings = update_settings(settings) if program_name == "net-responsibility-report" and @latestreports == false
		settings.each do |key, value|
			instance_variable_set("@#{key}", value)
			getter = proc do
				instance_variable_get("@#{key}")
			end
			setter = proc do |v|
				instance_variable_set("@#{key}", v)
			end
			self.class.send(:define_method,key,getter)
			self.class.send(:define_method,"#{key}=",setter)
		end
		if defined?(self.pidfile) && @daemonize == "pidfile"
			@daemonize = self.pidfile 
		end
	end
	
	def read_config(filename)
		settings = nil
		begin
			File.open(filename) { |f| settings = YAML::load(f) }
		rescue Errno::ENOENT
			if $0 =~ /configure-packages/
				return []
			else
				$stderr.print "The configuration file #{filename} doesn't exist.\n"
				exit(1)
			end
		end
		settings
	end
	
	def set_options
		@config = Options.default_configfile
		@daemonize = "pidfile"
		@debug = false
		@debugger = false
		@insidedaemon = false
		@testmail = false
		@mac = Options.get_mac
		@server = Options.set_server
		@latestreports = false
		@attachfile = Options.set_attachfile
		@setusername = false
		@setpassword = false
		@tokenmatch = false
		begin
			valid_options = [['--config','-c',GetoptLong::REQUIRED_ARGUMENT],
								['--nodaemon','-d',GetoptLong::NO_ARGUMENT],
								['--debug',GetoptLong::NO_ARGUMENT],
								['--debugger',GetoptLong::NO_ARGUMENT],
								['--help','-h',GetoptLong::NO_ARGUMENT],
								['--version','-v',GetoptLong::NO_ARGUMENT],
								['--insidedaemon',GetoptLong::NO_ARGUMENT],
								['--testmail',GetoptLong::NO_ARGUMENT],
								['--server',GetoptLong::REQUIRED_ARGUMENT],
								['--latestreports','-l',GetoptLong::OPTIONAL_ARGUMENT],
								['--attachfile','-a',GetoptLong::REQUIRED_ARGUMENT],
								['--tokenmatch',GetoptLong::NO_ARGUMENT],
								['--setusername',GetoptLong::REQUIRED_ARGUMENT],
								['--setpassword',GetoptLong::REQUIRED_ARGUMENT]
											]
			if $0 =~ /config-cli/
				$standalone = false
				valid_options.push(['--standalone',GetoptLong::NO_ARGUMENT])
			end
			opts = GetoptLong.new(*valid_options)
			opts.each do |option, argument|
				case option
					when '--help'
						usage program_name # this method must be defined in a file
															 # that requires this one.
						exit!(0)
					when '--nodaemon'
						@daemonize = false
					when '--config'
						@config = File.expand_path(argument)
					when '--version'
						puts "Net Responsibility #{@version}"
						puts "Copyright 2007-2011 by Scott Severance & Robert Rosman"
						puts "\nNet Responsibility is free software. You may distribute"
						puts "it under the terms of the GNU General Public License,"
						puts "version 2 or (at your option) any later version. Net"
						puts "Responsibility carries no warranty of any kind."
						exit!(0)
					when '--debugger'
						@debugger = $debug_available
						unless @debugger
							puts "The debugger isn't installed. Exiting."
							exit 1 
						end
					when '--debug'
						@debug = true
					when '--standalone'
						$standalone = true
					when '--insidedaemon'
						@insidedaemon = true
					when '--testmail'
						@testmail = true
					when '--server'
						@server = argument
					when '--latestreports'
						if argument == ''
							@latestreports = 5
						else
							@latestreports = argument
						end
					when '--attachfile'
						@attachfile = argument
					when '--setusername'
						@setusername = argument
					when '--setpassword'
						@setpassword = argument
					when '--tokenmatch'
						@tokenmatch = true
				end
			end
		rescue
			$stderr.print "\n"
			usage program_name
			exit 1
		end
	end
	
	def set_version
		v = nil
		File.open "#{$lib_dir}VERSION" do |f|
			v = f.read.chomp
		end
		v = "svn.#{DateTime.now.compact_date}" if v =~ /svn/i
		@version = v
	end
	
	def self.default_configfile
		if $lib_dir =~ Regexp.new("^/usr/share")
			'/etc/net-responsibility.conf'
		else
			"%s/net-responsibility.conf" % $0.gsub(Regexp.new("^(.*)/[^/]*$"), '\1')
		end
	end
	
	def self.get_mac
		IO.popen("ifconfig -a | grep HWaddr | cut -c39-") do |mac_addr|
			return mac_addr.gets.gsub(/\s*\n/, "")
		end
	end
	
	def self.set_server
		"www.netresponsibility.com"
	end
	
	def self.set_attachfile
		i = 1
		date = DateTime.now.compact_date
		while File.exists? "#{$lib_dir}reports/report_%s_%s.htm" % [date, i] or File.exists? "#{$lib_dir}reports/report_%s_%s.zip" % [date, i]
			i += 1
		end
		"#{$lib_dir}reports/report_%s_%s.htm" % [date, i]
	end
 
	def self.default_logfile
		'/var/log/net-responsibility.log'
		#File.expand_path('net-responsibility.log')
	end

	def to_s
		str = ""
		instance_variables.each do |var|
			str += "%s = %s\n" % [var.gsub(/^@*/,''),
										instance_variable_get(var).inspect]
		end
		str.chomp
	end

	def update_settings(settings = read_config(@config))
		begin
			sc = Server_connection.new(self, settings['online_user'])
			sc.get_config()
			settings = read_config("/tmp/nr.conf")
			@blacklist = sc.get_blacklists(settings['blacklist_download'])
			@whitelist = {} if settings["whitelist"] == nil
			@tokenmatch = true if settings['report_match'] == "advanced"
		rescue SocketError
			raise SocketError, "Couldn't connect to internet..."
		end
		settings
	end
	alias_method :inspect, :to_s
	attr_accessor :config, :daemonize, :debugger, :debug, :version, :insidedaemon, :mac, :server, :blacklist, 
		:whitelist, :testmail, :latestreports, :attachfile, :setusername, :setpassword, :tokenmatch
	private :read_config, :set_options, :set_version
end
