raise "Can't run this file directly" unless defined? $lib_dir
# Net Responsibility
#
# Copyright (C) 2007-2011 Scott Severance & Robert Rosman
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of the
# License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
# 02111-1307, USA.
#
# Author:
#	Scott Severance <http://www.scottseverance.us>

require "#{$lib_dir}options"
require "#{$lib_dir}my_date"
require "#{$lib_dir}exceptions"
require "#{$lib_dir}syslog"

class Report_mailer
	def initialize(options = nil)
		options = Options.new unless options
		@options = options
		unless options.respond_to? :smtp_server
			t  = "Your configuration file, #{options.config}, is missing the "
			t += "section 'smtp_server'. I can't continue without it. Please "
			t += "either repair the file, or uninstall Net Responsibility, "
			t += "allowing the uninstaller to remove the config file, then "
			t += "reinstall Net Responsibility.\n"
			t += "Exiting."
			Syslog.log t, 'syslog'
			exit 1
		end
		@smtp_options = options.smtp_server
		@smtp_options["email_from"] = options.email_from
		@smtp_options["email_to"] = options.email_to
		@smtp_options['name'] = options.name
		@smtp_options['use_smtp']
	end
	
	def send_message(message)
		raise SMTP_DisabledError unless @smtp_options['use_smtp']
		message_file = `mktemp -tq net-responsibility-mail.XXXXXXXXXXXXXXX`
		raise SMTP_DisabledError if $?.exitstatus != 0
		File.open(message_file, 'w') { |f| f.print message }
		attachfile = (File.exists? @options.attachfile) ? @options.attachfile : 'False'
		result = `python #{$lib_dir}send_report.py '#{message_file}' '/tmp/nr.conf' #{attachfile} #{@options.debug.to_s.capitalize}`
		Syslog.debug(:file => __FILE__, :line => __LINE__, :name => 'result', :obj => result)
		File.delete(message_file)
		case $?.exitstatus
			when 0
				"Success"
			when 4
				Syslog.log("Sending mail to the following addresses failed: #{result.split("\n").join(", ")}", "syslog")
				result
			when 2
				Syslog.log("send_report.py called incorrectly. Here's its usage message:\n#{result}", "syslog")
				raise ArgumentError, 'send_report.py called incorrectly'
			when 1
				raise "send-report.py exited due to an unhandled exception."
			else
				raise "send_report.py exited with unknown status #{$?.exitstatus}"
		end
	end
	
	def create_and_send(message)
		begin
			Syslog.log("Sending report",'syslog')
			send_message message
		rescue SMTP_DisabledError
			Syslog.log("SMTP is disabled. Sending report to standard out.","syslog")
			print message
		end
	end
end
