raise "Can't run this file directly" unless defined? $lib_dir
# Net Responsibility
#
# Copyright (C) 2007-2011 Scott Severance & Robert Rosman
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of the
# License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
# 02111-1307, USA.
#
# Author:
#	Scott Severance <http://www.scottseverance.us>

require "English"
require "#{$lib_dir}exceptions"

class Syslog
	def self.process_name=(process_name)
		@@process_name = "%s[%d]" % [process_name, $PID]
	end
	
	def self.log(message, log = 'daemon', level = "info")
		raise(SyslogError, "Process name not set") unless defined? @@process_name
		
		# We have to convert ` to ' and properly escape all single quotes
		msg = message.gsub(Regexp.new('`'),"'")
		msg.gsub!(Regexp.new("([a-zA-Z])'([a-zA-Z])"), '\1qwertyuiop\2')
		msg.gsub!(Regexp.new("'([^']*)'"),"'\\\\'" + '\1' + "\\\\''")
		msg.gsub!(/qwertyuiop/,"'\\\\''")
		
		`echo '#{msg}' | logger -sp #{log}.#{level} -t '#{@@process_name}'`
	end
	
	def self.log_exception(exception,
			log_message = "Exiting due to an unhandled exception",
			log = 'daemon',
			level = "info")
		msg = if exception.message
				"#{exception.message} (#{exception.class})"
				else exception.class
				end
		backtrace = exception.backtrace
		origin = backtrace.shift
		msg = "%s: %s" % [origin, msg]
		backtrace.each_index { |i| backtrace[i] = "=> from %s" % backtrace[i] }
		x = [log_message, msg]
		x += backtrace
		x.each { |line| Syslog.log line.chomp, log, level }
	end
	
	def self.debug(o)
		opts = {:name => nil, :file => nil, :line => nil,
				:obj => "No debug object specified", :log => 'syslog',
				:options => $options}.merge(o)
		return unless opts[:options].debug
		out  = ["---------- Debugging Information ----------"]
		out.push "File: #{opts[:file]}" if opts[:file]
		out.push "Line: #{opts[:line]}" if opts[:line]
		out.push "Object name: #{opts[:name]}" if opts[:name]
		out.push "Object class: #{opts[:obj].class}"
		out.push opts[:obj].inspect
		out.push "<<<<< End >>>>>"
		self.log out.join("\n"), opts[:log], 'debug'
	end
	
	def initialize(process_name)
		Syslog.process_name = process_name
	end
	
	def log(message, log = 'daemon', level = 'info')
		Syslog.log message, log, level
	end
end
